from yeying.api.common import message_pb2 as _message_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class SearchNamespaceRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: SearchNamespaceRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[SearchNamespaceRequestBody, _Mapping]] = ...,
    ) -> None: ...

class SearchNamespaceRequestBody(_message.Message):
    __slots__ = ("condition", "page")
    CONDITION_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    condition: SearchNamespaceCondition
    page: _message_pb2.RequestPage
    def __init__(
        self,
        condition: _Optional[_Union[SearchNamespaceCondition, _Mapping]] = ...,
        page: _Optional[_Union[_message_pb2.RequestPage, _Mapping]] = ...,
    ) -> None: ...

class SearchNamespaceCondition(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class NamespaceDetailRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: NamespaceDetailRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[NamespaceDetailRequestBody, _Mapping]] = ...,
    ) -> None: ...

class NamespaceDetailRequestBody(_message.Message):
    __slots__ = ("uid",)
    UID_FIELD_NUMBER: _ClassVar[int]
    uid: str
    def __init__(self, uid: _Optional[str] = ...) -> None: ...

class NamespaceDetailResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: NamespaceDetailResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[NamespaceDetailResponseBody, _Mapping]] = ...,
    ) -> None: ...

class NamespaceDetailResponseBody(_message.Message):
    __slots__ = ("status", "namespace")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    namespace: NamespaceMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        namespace: _Optional[_Union[NamespaceMetadata, _Mapping]] = ...,
    ) -> None: ...

class SearchNamespaceResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: SearchNamespaceResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[SearchNamespaceResponseBody, _Mapping]] = ...,
    ) -> None: ...

class SearchNamespaceResponseBody(_message.Message):
    __slots__ = ("status", "namespaces")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    NAMESPACES_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    namespaces: _containers.RepeatedCompositeFieldContainer[NamespaceMetadata]
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        namespaces: _Optional[_Iterable[_Union[NamespaceMetadata, _Mapping]]] = ...,
    ) -> None: ...

class CreateNamespaceRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CreateNamespaceRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[CreateNamespaceRequestBody, _Mapping]] = ...,
    ) -> None: ...

class CreateNamespaceRequestBody(_message.Message):
    __slots__ = ("namespace",)
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    namespace: NamespaceMetadata
    def __init__(self, namespace: _Optional[_Union[NamespaceMetadata, _Mapping]] = ...) -> None: ...

class CreateNamespaceResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CreateNamespaceResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[CreateNamespaceResponseBody, _Mapping]] = ...,
    ) -> None: ...

class CreateNamespaceResponseBody(_message.Message):
    __slots__ = ("status", "namespace")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    namespace: NamespaceMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        namespace: _Optional[_Union[NamespaceMetadata, _Mapping]] = ...,
    ) -> None: ...

class UpdateNamespaceRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: UpdateNamespaceRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[UpdateNamespaceRequestBody, _Mapping]] = ...,
    ) -> None: ...

class UpdateNamespaceRequestBody(_message.Message):
    __slots__ = ("namespace",)
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    namespace: NamespaceMetadata
    def __init__(self, namespace: _Optional[_Union[NamespaceMetadata, _Mapping]] = ...) -> None: ...

class UpdateNamespaceResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: UpdateNamespaceResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[UpdateNamespaceResponseBody, _Mapping]] = ...,
    ) -> None: ...

class UpdateNamespaceResponseBody(_message.Message):
    __slots__ = ("status", "namespace")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    namespace: NamespaceMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        namespace: _Optional[_Union[NamespaceMetadata, _Mapping]] = ...,
    ) -> None: ...

class DeleteNamespaceRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DeleteNamespaceRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DeleteNamespaceRequestBody, _Mapping]] = ...,
    ) -> None: ...

class DeleteNamespaceRequestBody(_message.Message):
    __slots__ = ("uid",)
    UID_FIELD_NUMBER: _ClassVar[int]
    uid: str
    def __init__(self, uid: _Optional[str] = ...) -> None: ...

class DeleteNamespaceResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DeleteNamespaceResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DeleteNamespaceResponseBody, _Mapping]] = ...,
    ) -> None: ...

class DeleteNamespaceResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class NamespaceMetadata(_message.Message):
    __slots__ = ("owner", "participants", "uid", "name", "description", "createdAt", "updatedAt", "signature")
    OWNER_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANTS_FIELD_NUMBER: _ClassVar[int]
    UID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    UPDATEDAT_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    owner: str
    participants: str
    uid: str
    name: str
    description: str
    createdAt: str
    updatedAt: str
    signature: str
    def __init__(
        self,
        owner: _Optional[str] = ...,
        participants: _Optional[str] = ...,
        uid: _Optional[str] = ...,
        name: _Optional[str] = ...,
        description: _Optional[str] = ...,
        createdAt: _Optional[str] = ...,
        updatedAt: _Optional[str] = ...,
        signature: _Optional[str] = ...,
    ) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/certificate/certificate.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/certificate/certificate.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n(yeying/api/certificate/certificate.proto\x12\x16yeying.api.certificate\x1a\x1fyeying/api/common/message.proto"v\n\x0bSignRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.certificate.SignRequestBody".\n\x0fSignRequestBody\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12\x0b\n\x03\x63sr\x18\x02 \x01(\t"x\n\x0cSignResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.certificate.SignResponseBody".\n\x13\x43\x65rtificateMetadata\x12\x0b\n\x03\x63rt\x18\x01 \x01(\t\x12\n\n\x02\x63\x61\x18\x02 \x01(\t"\x87\x01\n\x10SignResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12@\n\x0b\x63\x65rtificate\x18\x02 \x01(\x0b\x32+.yeying.api.certificate.CertificateMetadata">\n\nGetRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader"v\n\x0bGetResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.certificate.GetResponseBody"\x86\x01\n\x0fGetResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12@\n\x0b\x63\x65rtificate\x18\x02 \x01(\x0b\x32+.yeying.api.certificate.CertificateMetadata2\xb4\x01\n\x0b\x43\x65rtificate\x12S\n\x04Sign\x12#.yeying.api.certificate.SignRequest\x1a$.yeying.api.certificate.SignResponse"\x00\x12P\n\x03Get\x12".yeying.api.certificate.GetRequest\x1a#.yeying.api.certificate.GetResponse"\x00\x42\x18Z\x16yeying/api/certificateb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.certificate.certificate_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\026yeying/api/certificate"
    _globals["_SIGNREQUEST"]._serialized_start = 101
    _globals["_SIGNREQUEST"]._serialized_end = 219
    _globals["_SIGNREQUESTBODY"]._serialized_start = 221
    _globals["_SIGNREQUESTBODY"]._serialized_end = 267
    _globals["_SIGNRESPONSE"]._serialized_start = 269
    _globals["_SIGNRESPONSE"]._serialized_end = 389
    _globals["_CERTIFICATEMETADATA"]._serialized_start = 391
    _globals["_CERTIFICATEMETADATA"]._serialized_end = 437
    _globals["_SIGNRESPONSEBODY"]._serialized_start = 440
    _globals["_SIGNRESPONSEBODY"]._serialized_end = 575
    _globals["_GETREQUEST"]._serialized_start = 577
    _globals["_GETREQUEST"]._serialized_end = 639
    _globals["_GETRESPONSE"]._serialized_start = 641
    _globals["_GETRESPONSE"]._serialized_end = 759
    _globals["_GETRESPONSEBODY"]._serialized_start = 762
    _globals["_GETRESPONSEBODY"]._serialized_end = 896
    _globals["_CERTIFICATE"]._serialized_start = 899
    _globals["_CERTIFICATE"]._serialized_end = 1079
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/common/message.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/common/message.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import code_pb2 as yeying_dot_api_dot_common_dot_code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1fyeying/api/common/message.proto\x12\x11yeying.api.common\x1a\x1cyeying/api/common/code.proto"\x9f\x01\n\rMessageHeader\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\x39\n\x08\x61uthType\x18\x02 \x01(\x0e\x32\'.yeying.api.common.AuthenticateTypeEnum\x12\x13\n\x0b\x61uthContent\x18\x03 \x01(\t\x12\r\n\x05nonce\x18\x04 \x01(\t\x12\x11\n\ttimestamp\x18\x05 \x01(\t\x12\x0f\n\x07version\x18\x06 \x01(\r"T\n\x0eResponseStatus\x12\x31\n\x04\x63ode\x18\x01 \x01(\x0e\x32#.yeying.api.common.ResponseCodeEnum\x12\x0f\n\x07message\x18\x02 \x01(\t"=\n\x0cResponsePage\x12\r\n\x05total\x18\x01 \x01(\r\x12\x0c\n\x04page\x18\x03 \x01(\r\x12\x10\n\x08pageSize\x18\x04 \x01(\r"-\n\x0bRequestPage\x12\x0c\n\x04page\x18\x01 \x01(\r\x12\x10\n\x08pageSize\x18\x02 \x01(\rB\x13Z\x11yeying/api/commonb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.common.message_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\021yeying/api/common"
    _globals["_MESSAGEHEADER"]._serialized_start = 85
    _globals["_MESSAGEHEADER"]._serialized_end = 244
    _globals["_RESPONSESTATUS"]._serialized_start = 246
    _globals["_RESPONSESTATUS"]._serialized_end = 330
    _globals["_RESPONSEPAGE"]._serialized_start = 332
    _globals["_RESPONSEPAGE"]._serialized_end = 393
    _globals["_REQUESTPAGE"]._serialized_start = 395
    _globals["_REQUESTPAGE"]._serialized_end = 440
# @@protoc_insertion_point(module_scope)



# Generated by protobuf_init. Do not edit manually.
from .content_pb2 import ValidateRequest
from .content_pb2 import ValidateResponse
from .content_pb2_grpc import ContentServicer
from .content_pb2_grpc import ContentStub
from .content_pb2_grpc import add_ContentServicer_to_server
from .content_pb2_grpc import Content



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/apps/zuoyepigai/task.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/apps/zuoyepigai/task.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yeying.api.apps.zuoyepigai import imagecontent_pb2 as yeying_dot_api_dot_apps_dot_zuoyepigai_dot_imagecontent__pb2
from yeying.api.apps.zuoyepigai import meta_pb2 as yeying_dot_api_dot_apps_dot_zuoyepigai_dot_meta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n%yeying/api/apps/zuoyepigai/task.proto\x12\x1ayeying.api.apps.zuoyepigai\x1a\x1fyeying/api/common/message.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a-yeying/api/apps/zuoyepigai/imagecontent.proto\x1a%yeying/api/apps/zuoyepigai/meta.proto"\x80\x01\n\x0e\x41\x64\x64TaskRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12<\n\x04\x62ody\x18\x02 \x01(\x0b\x32..yeying.api.apps.zuoyepigai.AddTaskRequestBody"L\n\x12\x41\x64\x64TaskRequestBody\x12\x36\n\x04meta\x18\x01 \x01(\x0b\x32(.yeying.api.apps.zuoyepigai.TaskMetadata"\x82\x01\n\x0f\x41\x64\x64TaskResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12=\n\x04\x62ody\x18\x02 \x01(\x0b\x32/.yeying.api.apps.zuoyepigai.AddTaskResponseBody"\x80\x01\n\x13\x41\x64\x64TaskResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x36\n\x04meta\x18\x02 \x01(\x0b\x32(.yeying.api.apps.zuoyepigai.TaskMetadata"\x86\x01\n\x11\x44\x65tailTaskRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12?\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x31.yeying.api.apps.zuoyepigai.DetailTaskRequestBody"$\n\x15\x44\x65tailTaskRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x88\x01\n\x12\x44\x65tailTaskResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.apps.zuoyepigai.DetailTaskResponseBody"\xc3\x01\n\x16\x44\x65tailTaskResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x36\n\x04meta\x18\x02 \x01(\x0b\x32(.yeying.api.apps.zuoyepigai.TaskMetadata\x12>\n\x0bstudentList\x18\x03 \x03(\x0b\x32).yeying.api.apps.zuoyepigai.GroupMetaData"\x82\x01\n\x0fListTaskRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12=\n\x04\x62ody\x18\x02 \x01(\x0b\x32/.yeying.api.apps.zuoyepigai.ListTaskRequestBody"\xec\x01\n\x13ListTaskRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\x0e\n\x06tagUid\x18\x02 \x01(\t\x12\x10\n\x08taskName\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12.\n\tpageIndex\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12-\n\x08pageSize\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x0e\n\x06status\x18\x07 \x01(\x05\x12\x11\n\tstartTime\x18\x08 \x01(\x03\x12\x0f\n\x07\x65ndTime\x18\t \x01(\x03"\x84\x01\n\x10ListTaskResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12>\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x30.yeying.api.apps.zuoyepigai.ListTaskResponseBody"\x90\x01\n\x14ListTaskResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x36\n\x04list\x18\x02 \x03(\x0b\x32(.yeying.api.apps.zuoyepigai.TaskMetadata\x12\r\n\x05total\x18\x03 \x01(\x04"\x8a\x01\n\x13TagCountTaskRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.apps.zuoyepigai.TagCountTaskRequestBody"&\n\x17TagCountTaskRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t"\x8c\x01\n\x14TagCountTaskResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.apps.zuoyepigai.TagCountTaskResponseBody"\x85\x01\n\x18TagCountTaskResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x36\n\x04meta\x18\x02 \x03(\x0b\x32(.yeying.api.apps.zuoyepigai.TagCountMeta"\x86\x01\n\x11UpdateTaskRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12?\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x31.yeying.api.apps.zuoyepigai.UpdateTaskRequestBody"O\n\x15UpdateTaskRequestBody\x12\x36\n\x04meta\x18\x01 \x01(\x0b\x32(.yeying.api.apps.zuoyepigai.TaskMetadata"\x88\x01\n\x12UpdateTaskResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.apps.zuoyepigai.UpdateTaskResponseBody"\x83\x01\n\x16UpdateTaskResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x36\n\x04meta\x18\x02 \x01(\x0b\x32(.yeying.api.apps.zuoyepigai.TaskMetadata"\x86\x01\n\x11\x44\x65leteTaskRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12?\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x31.yeying.api.apps.zuoyepigai.DeleteTaskRequestBody"$\n\x15\x44\x65leteTaskRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x88\x01\n\x12\x44\x65leteTaskResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.apps.zuoyepigai.DeleteTaskResponseBody"\x83\x01\n\x16\x44\x65leteTaskResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x36\n\x04meta\x18\x02 \x01(\x0b\x32(.yeying.api.apps.zuoyepigai.TaskMetadata2\xff\x04\n\x04Task\x12`\n\x03\x41\x64\x64\x12*.yeying.api.apps.zuoyepigai.AddTaskRequest\x1a+.yeying.api.apps.zuoyepigai.AddTaskResponse"\x00\x12i\n\x06\x44\x65tail\x12-.yeying.api.apps.zuoyepigai.DetailTaskRequest\x1a..yeying.api.apps.zuoyepigai.DetailTaskResponse"\x00\x12\x63\n\x04List\x12+.yeying.api.apps.zuoyepigai.ListTaskRequest\x1a,.yeying.api.apps.zuoyepigai.ListTaskResponse"\x00\x12o\n\x08TagCount\x12/.yeying.api.apps.zuoyepigai.TagCountTaskRequest\x1a\x30.yeying.api.apps.zuoyepigai.TagCountTaskResponse"\x00\x12i\n\x06Update\x12-.yeying.api.apps.zuoyepigai.UpdateTaskRequest\x1a..yeying.api.apps.zuoyepigai.UpdateTaskResponse"\x00\x12i\n\x06\x44\x65lete\x12-.yeying.api.apps.zuoyepigai.DeleteTaskRequest\x1a..yeying.api.apps.zuoyepigai.DeleteTaskResponse"\x00\x42\x1cZ\x1ayeying/api/apps/zuoyepigaib\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.apps.zuoyepigai.task_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\032yeying/api/apps/zuoyepigai"
    _globals["_ADDTASKREQUEST"]._serialized_start = 221
    _globals["_ADDTASKREQUEST"]._serialized_end = 349
    _globals["_ADDTASKREQUESTBODY"]._serialized_start = 351
    _globals["_ADDTASKREQUESTBODY"]._serialized_end = 427
    _globals["_ADDTASKRESPONSE"]._serialized_start = 430
    _globals["_ADDTASKRESPONSE"]._serialized_end = 560
    _globals["_ADDTASKRESPONSEBODY"]._serialized_start = 563
    _globals["_ADDTASKRESPONSEBODY"]._serialized_end = 691
    _globals["_DETAILTASKREQUEST"]._serialized_start = 694
    _globals["_DETAILTASKREQUEST"]._serialized_end = 828
    _globals["_DETAILTASKREQUESTBODY"]._serialized_start = 830
    _globals["_DETAILTASKREQUESTBODY"]._serialized_end = 866
    _globals["_DETAILTASKRESPONSE"]._serialized_start = 869
    _globals["_DETAILTASKRESPONSE"]._serialized_end = 1005
    _globals["_DETAILTASKRESPONSEBODY"]._serialized_start = 1008
    _globals["_DETAILTASKRESPONSEBODY"]._serialized_end = 1203
    _globals["_LISTTASKREQUEST"]._serialized_start = 1206
    _globals["_LISTTASKREQUEST"]._serialized_end = 1336
    _globals["_LISTTASKREQUESTBODY"]._serialized_start = 1339
    _globals["_LISTTASKREQUESTBODY"]._serialized_end = 1575
    _globals["_LISTTASKRESPONSE"]._serialized_start = 1578
    _globals["_LISTTASKRESPONSE"]._serialized_end = 1710
    _globals["_LISTTASKRESPONSEBODY"]._serialized_start = 1713
    _globals["_LISTTASKRESPONSEBODY"]._serialized_end = 1857
    _globals["_TAGCOUNTTASKREQUEST"]._serialized_start = 1860
    _globals["_TAGCOUNTTASKREQUEST"]._serialized_end = 1998
    _globals["_TAGCOUNTTASKREQUESTBODY"]._serialized_start = 2000
    _globals["_TAGCOUNTTASKREQUESTBODY"]._serialized_end = 2038
    _globals["_TAGCOUNTTASKRESPONSE"]._serialized_start = 2041
    _globals["_TAGCOUNTTASKRESPONSE"]._serialized_end = 2181
    _globals["_TAGCOUNTTASKRESPONSEBODY"]._serialized_start = 2184
    _globals["_TAGCOUNTTASKRESPONSEBODY"]._serialized_end = 2317
    _globals["_UPDATETASKREQUEST"]._serialized_start = 2320
    _globals["_UPDATETASKREQUEST"]._serialized_end = 2454
    _globals["_UPDATETASKREQUESTBODY"]._serialized_start = 2456
    _globals["_UPDATETASKREQUESTBODY"]._serialized_end = 2535
    _globals["_UPDATETASKRESPONSE"]._serialized_start = 2538
    _globals["_UPDATETASKRESPONSE"]._serialized_end = 2674
    _globals["_UPDATETASKRESPONSEBODY"]._serialized_start = 2677
    _globals["_UPDATETASKRESPONSEBODY"]._serialized_end = 2808
    _globals["_DELETETASKREQUEST"]._serialized_start = 2811
    _globals["_DELETETASKREQUEST"]._serialized_end = 2945
    _globals["_DELETETASKREQUESTBODY"]._serialized_start = 2947
    _globals["_DELETETASKREQUESTBODY"]._serialized_end = 2983
    _globals["_DELETETASKRESPONSE"]._serialized_start = 2986
    _globals["_DELETETASKRESPONSE"]._serialized_end = 3122
    _globals["_DELETETASKRESPONSEBODY"]._serialized_start = 3125
    _globals["_DELETETASKRESPONSEBODY"]._serialized_end = 3256
    _globals["_TASK"]._serialized_start = 3259
    _globals["_TASK"]._serialized_end = 3898
# @@protoc_insertion_point(module_scope)



from yeying.api.common import message_pb2 as _message_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateMemoryRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CreateMemoryRequestBody
    def __init__(self, header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ..., body: _Optional[_Union[CreateMemoryRequestBody, _Mapping]] = ...) -> None: ...

class CreateMemoryRequestBody(_message.Message):
    __slots__ = ("domain",)
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    domain: str
    def __init__(self, domain: _Optional[str] = ...) -> None: ...

class CreateMemoryResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CreateMemoryResponseBody
    def __init__(self, header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ..., body: _Optional[_Union[CreateMemoryResponseBody, _Mapping]] = ...) -> None: ...

class CreateMemoryResponseBody(_message.Message):
    __slots__ = ("status", "memory_id")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    MEMORY_ID_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    memory_id: str
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ..., memory_id: _Optional[str] = ...) -> None: ...

class AddMemoryRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AddMemoryRequestBody
    def __init__(self, header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ..., body: _Optional[_Union[AddMemoryRequestBody, _Mapping]] = ...) -> None: ...

class AddMemoryRequestBody(_message.Message):
    __slots__ = ("memory_id", "url")
    MEMORY_ID_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    memory_id: str
    url: str
    def __init__(self, memory_id: _Optional[str] = ..., url: _Optional[str] = ...) -> None: ...

class AddMemoryResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AddMemoryResponseBody
    def __init__(self, header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ..., body: _Optional[_Union[AddMemoryResponseBody, _Mapping]] = ...) -> None: ...

class AddMemoryResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class DeleteMemoryRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DeleteMemoryRequestBody
    def __init__(self, header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ..., body: _Optional[_Union[DeleteMemoryRequestBody, _Mapping]] = ...) -> None: ...

class DeleteMemoryRequestBody(_message.Message):
    __slots__ = ("memory_id", "url")
    MEMORY_ID_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    memory_id: str
    url: str
    def __init__(self, memory_id: _Optional[str] = ..., url: _Optional[str] = ...) -> None: ...

class DeleteMemoryResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DeleteMemoryResponseBody
    def __init__(self, header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ..., body: _Optional[_Union[DeleteMemoryResponseBody, _Mapping]] = ...) -> None: ...

class DeleteMemoryResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yeying.api.rag import rag_pb2 as yeying_dot_api_dot_rag_dot_rag__pb2

GRPC_GENERATED_VERSION = '1.73.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yeying/api/rag/rag_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class RAGStub(object):
    """*
    记忆模块
    对应的 DB 表：rag.memory
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateSession = channel.unary_unary(
                '/yeying.api.rag.RAG/CreateSession',
                request_serializer=yeying_dot_api_dot_rag_dot_rag__pb2.CreateSessionRequest.SerializeToString,
                response_deserializer=yeying_dot_api_dot_rag_dot_rag__pb2.CreateSessionResponse.FromString,
                _registered_method=True)
        self.AddMessage = channel.unary_unary(
                '/yeying.api.rag.RAG/AddMessage',
                request_serializer=yeying_dot_api_dot_rag_dot_rag__pb2.AddMessageRequest.SerializeToString,
                response_deserializer=yeying_dot_api_dot_rag_dot_rag__pb2.AddMessageResponse.FromString,
                _registered_method=True)
        self.DeleteMessage = channel.unary_unary(
                '/yeying.api.rag.RAG/DeleteMessage',
                request_serializer=yeying_dot_api_dot_rag_dot_rag__pb2.DeleteMessageRequest.SerializeToString,
                response_deserializer=yeying_dot_api_dot_rag_dot_rag__pb2.DeleteMessageResponse.FromString,
                _registered_method=True)


class RAGServicer(object):
    """*
    记忆模块
    对应的 DB 表：rag.memory
    """

    def CreateSession(self, request, context):
        """创建会话
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddMessage(self, request, context):
        """添加消息
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteMessage(self, request, context):
        """删除消息
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RAGServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateSession': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSession,
                    request_deserializer=yeying_dot_api_dot_rag_dot_rag__pb2.CreateSessionRequest.FromString,
                    response_serializer=yeying_dot_api_dot_rag_dot_rag__pb2.CreateSessionResponse.SerializeToString,
            ),
            'AddMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.AddMessage,
                    request_deserializer=yeying_dot_api_dot_rag_dot_rag__pb2.AddMessageRequest.FromString,
                    response_serializer=yeying_dot_api_dot_rag_dot_rag__pb2.AddMessageResponse.SerializeToString,
            ),
            'DeleteMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteMessage,
                    request_deserializer=yeying_dot_api_dot_rag_dot_rag__pb2.DeleteMessageRequest.FromString,
                    response_serializer=yeying_dot_api_dot_rag_dot_rag__pb2.DeleteMessageResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yeying.api.rag.RAG', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yeying.api.rag.RAG', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class RAG(object):
    """*
    记忆模块
    对应的 DB 表：rag.memory
    """

    @staticmethod
    def CreateSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yeying.api.rag.RAG/CreateSession',
            yeying_dot_api_dot_rag_dot_rag__pb2.CreateSessionRequest.SerializeToString,
            yeying_dot_api_dot_rag_dot_rag__pb2.CreateSessionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AddMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yeying.api.rag.RAG/AddMessage',
            yeying_dot_api_dot_rag_dot_rag__pb2.AddMessageRequest.SerializeToString,
            yeying_dot_api_dot_rag_dot_rag__pb2.AddMessageResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yeying.api.rag.RAG/DeleteMessage',
            yeying_dot_api_dot_rag_dot_rag__pb2.DeleteMessageRequest.SerializeToString,
            yeying_dot_api_dot_rag_dot_rag__pb2.DeleteMessageResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/mcp/resource.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/mcp/resource.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.common import code_pb2 as yeying_dot_api_dot_common_dot_code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n\x1dyeying/api/mcp/resource.proto\x12\x0eyeying.api.mcp\x1a\x1fyeying/api/common/message.proto\x1a\x1cyeying/api/common/code.proto2\n\n\x08ResourceB\x10Z\x0eyeying/api/mcpb\x06proto3"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.mcp.resource_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\016yeying/api/mcp"
    _globals["_RESOURCE"]._serialized_start = 112
    _globals["_RESOURCE"]._serialized_end = 122
# @@protoc_insertion_point(module_scope)



# Generated by protobuf_init. Do not edit manually.
from .bulletin_pb2 import BulletinListRequest
from .bulletin_pb2 import BulletinListRequestBody
from .bulletin_pb2 import BulletinListResponse
from .bulletin_pb2 import BulletinListResponseBody
from .bulletin_pb2 import SolutionMetadata
from .bulletin_pb2 import SolutionCard
from .bulletin_pb2 import BulletinCodeEnum
from .bulletin_pb2_grpc import BulletinServicer
from .bulletin_pb2_grpc import BulletinStub
from .bulletin_pb2_grpc import add_BulletinServicer_to_server
from .bulletin_pb2_grpc import Bulletin



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings


GRPC_GENERATED_VERSION = "1.68.1"
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower

    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f"The grpc package installed is at version {GRPC_VERSION},"
        + f" but the generated code in yeying/api/mcp/prompt_pb2_grpc.py depends on"
        + f" grpcio>={GRPC_GENERATED_VERSION}."
        + f" Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}"
        + f" or downgrade your generated code using grpcio-tools<={GRPC_VERSION}."
    )


class PromptStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """


class PromptServicer(object):
    """Missing associated documentation comment in .proto file."""


def add_PromptServicer_to_server(servicer, server):
    rpc_method_handlers = {}
    generic_handler = grpc.method_handlers_generic_handler("yeying.api.mcp.Prompt", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers("yeying.api.mcp.Prompt", rpc_method_handlers)


# This class is part of an EXPERIMENTAL API.
class Prompt(object):
    """Missing associated documentation comment in .proto file."""



from yeying.api.common import message_pb2 as _message_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class TaskCodeEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    TASK_CODE_UNKNOWN: _ClassVar[TaskCodeEnum]
    TASK_CODE_STATISTIC: _ClassVar[TaskCodeEnum]

TASK_CODE_UNKNOWN: TaskCodeEnum
TASK_CODE_STATISTIC: TaskCodeEnum

class CreateTaskRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class CreateTaskResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class TaskMetadata(_message.Message):
    __slots__ = ("uid", "code", "creator", "participant", "terminator", "createdAt", "content")
    UID_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    TERMINATOR_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    uid: str
    code: TaskCodeEnum
    creator: str
    participant: str
    terminator: str
    createdAt: str
    content: str
    def __init__(
        self,
        uid: _Optional[str] = ...,
        code: _Optional[_Union[TaskCodeEnum, str]] = ...,
        creator: _Optional[str] = ...,
        participant: _Optional[str] = ...,
        terminator: _Optional[str] = ...,
        createdAt: _Optional[str] = ...,
        content: _Optional[str] = ...,
    ) -> None: ...

class FetchTaskResponse(_message.Message):
    __slots__ = ("tasks",)
    TASKS_FIELD_NUMBER: _ClassVar[int]
    tasks: _containers.RepeatedCompositeFieldContainer[TaskMetadata]
    def __init__(self, tasks: _Optional[_Iterable[_Union[TaskMetadata, _Mapping]]] = ...) -> None: ...



from yeying.api.apps.zuoyepigai import imagecontent_pb2 as _imagecontent_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class GroupMetaData(_message.Message):
    __slots__ = ("uid", "did", "groupName", "createdAt", "updatedAt", "isDeleted", "teacherDid", "studentName")
    UID_FIELD_NUMBER: _ClassVar[int]
    DID_FIELD_NUMBER: _ClassVar[int]
    GROUPNAME_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    UPDATEDAT_FIELD_NUMBER: _ClassVar[int]
    ISDELETED_FIELD_NUMBER: _ClassVar[int]
    TEACHERDID_FIELD_NUMBER: _ClassVar[int]
    STUDENTNAME_FIELD_NUMBER: _ClassVar[int]
    uid: str
    did: str
    groupName: str
    createdAt: int
    updatedAt: int
    isDeleted: bool
    teacherDid: str
    studentName: str
    def __init__(
        self,
        uid: _Optional[str] = ...,
        did: _Optional[str] = ...,
        groupName: _Optional[str] = ...,
        createdAt: _Optional[int] = ...,
        updatedAt: _Optional[int] = ...,
        isDeleted: bool = ...,
        teacherDid: _Optional[str] = ...,
        studentName: _Optional[str] = ...,
    ) -> None: ...

class ArchiveMetadata(_message.Message):
    __slots__ = (
        "uid",
        "name",
        "studentDid",
        "teacherDid",
        "subject",
        "createdAt",
        "updatedAt",
        "isDeleted",
        "telephone",
        "email",
        "status",
    )
    UID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    STUDENTDID_FIELD_NUMBER: _ClassVar[int]
    TEACHERDID_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    UPDATEDAT_FIELD_NUMBER: _ClassVar[int]
    ISDELETED_FIELD_NUMBER: _ClassVar[int]
    TELEPHONE_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    uid: str
    name: str
    studentDid: str
    teacherDid: str
    subject: str
    createdAt: int
    updatedAt: int
    isDeleted: bool
    telephone: str
    email: str
    status: str
    def __init__(
        self,
        uid: _Optional[str] = ...,
        name: _Optional[str] = ...,
        studentDid: _Optional[str] = ...,
        teacherDid: _Optional[str] = ...,
        subject: _Optional[str] = ...,
        createdAt: _Optional[int] = ...,
        updatedAt: _Optional[int] = ...,
        isDeleted: bool = ...,
        telephone: _Optional[str] = ...,
        email: _Optional[str] = ...,
        status: _Optional[str] = ...,
    ) -> None: ...

class HomeworkMetadata(_message.Message):
    __slots__ = ("uid", "did", "subject", "testPaperUid", "createdAt", "updatedAt", "isDeleted")
    UID_FIELD_NUMBER: _ClassVar[int]
    DID_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    TESTPAPERUID_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    UPDATEDAT_FIELD_NUMBER: _ClassVar[int]
    ISDELETED_FIELD_NUMBER: _ClassVar[int]
    uid: str
    did: str
    subject: str
    testPaperUid: str
    createdAt: int
    updatedAt: int
    isDeleted: bool
    def __init__(
        self,
        uid: _Optional[str] = ...,
        did: _Optional[str] = ...,
        subject: _Optional[str] = ...,
        testPaperUid: _Optional[str] = ...,
        createdAt: _Optional[int] = ...,
        updatedAt: _Optional[int] = ...,
        isDeleted: bool = ...,
    ) -> None: ...

class MistakesMetadata(_message.Message):
    __slots__ = ("uid", "question", "answer", "createdAt", "updatedAt", "isDeleted")
    UID_FIELD_NUMBER: _ClassVar[int]
    QUESTION_FIELD_NUMBER: _ClassVar[int]
    ANSWER_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    UPDATEDAT_FIELD_NUMBER: _ClassVar[int]
    ISDELETED_FIELD_NUMBER: _ClassVar[int]
    uid: str
    question: str
    answer: str
    createdAt: int
    updatedAt: int
    isDeleted: bool
    def __init__(
        self,
        uid: _Optional[str] = ...,
        question: _Optional[str] = ...,
        answer: _Optional[str] = ...,
        createdAt: _Optional[int] = ...,
        updatedAt: _Optional[int] = ...,
        isDeleted: bool = ...,
    ) -> None: ...

class MessageMetadata(_message.Message):
    __slots__ = ("uid", "title", "type", "content", "createdAt", "updatedAt", "isDeleted")
    UID_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    UPDATEDAT_FIELD_NUMBER: _ClassVar[int]
    ISDELETED_FIELD_NUMBER: _ClassVar[int]
    uid: str
    title: str
    type: int
    content: str
    createdAt: int
    updatedAt: int
    isDeleted: bool
    def __init__(
        self,
        uid: _Optional[str] = ...,
        title: _Optional[str] = ...,
        type: _Optional[int] = ...,
        content: _Optional[str] = ...,
        createdAt: _Optional[int] = ...,
        updatedAt: _Optional[int] = ...,
        isDeleted: bool = ...,
    ) -> None: ...

class TaskMetadata(_message.Message):
    __slots__ = (
        "uid",
        "name",
        "description",
        "tagUid",
        "did",
        "studentDidList",
        "createdAt",
        "updatedAt",
        "startTime",
        "endTime",
        "isDeleted",
        "status",
    )
    UID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    TAGUID_FIELD_NUMBER: _ClassVar[int]
    DID_FIELD_NUMBER: _ClassVar[int]
    STUDENTDIDLIST_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    UPDATEDAT_FIELD_NUMBER: _ClassVar[int]
    STARTTIME_FIELD_NUMBER: _ClassVar[int]
    ENDTIME_FIELD_NUMBER: _ClassVar[int]
    ISDELETED_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    uid: str
    name: str
    description: str
    tagUid: str
    did: str
    studentDidList: str
    createdAt: int
    updatedAt: int
    startTime: int
    endTime: int
    isDeleted: bool
    status: _imagecontent_pb2.TaskStatusEnum
    def __init__(
        self,
        uid: _Optional[str] = ...,
        name: _Optional[str] = ...,
        description: _Optional[str] = ...,
        tagUid: _Optional[str] = ...,
        did: _Optional[str] = ...,
        studentDidList: _Optional[str] = ...,
        createdAt: _Optional[int] = ...,
        updatedAt: _Optional[int] = ...,
        startTime: _Optional[int] = ...,
        endTime: _Optional[int] = ...,
        isDeleted: bool = ...,
        status: _Optional[_Union[_imagecontent_pb2.TaskStatusEnum, str]] = ...,
    ) -> None: ...

class TagCountMeta(_message.Message):
    __slots__ = ("tagUid", "tagName", "count")
    TAGUID_FIELD_NUMBER: _ClassVar[int]
    TAGNAME_FIELD_NUMBER: _ClassVar[int]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    tagUid: str
    tagName: str
    count: int
    def __init__(
        self, tagUid: _Optional[str] = ..., tagName: _Optional[str] = ..., count: _Optional[int] = ...
    ) -> None: ...

class TaskTagMetadata(_message.Message):
    __slots__ = ("uid", "name", "did", "createdAt", "updatedAt", "isDeleted")
    UID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DID_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    UPDATEDAT_FIELD_NUMBER: _ClassVar[int]
    ISDELETED_FIELD_NUMBER: _ClassVar[int]
    uid: str
    name: str
    did: str
    createdAt: int
    updatedAt: int
    isDeleted: bool
    def __init__(
        self,
        uid: _Optional[str] = ...,
        name: _Optional[str] = ...,
        did: _Optional[str] = ...,
        createdAt: _Optional[int] = ...,
        updatedAt: _Optional[int] = ...,
        isDeleted: bool = ...,
    ) -> None: ...

class WarehouseMetadata(_message.Message):
    __slots__ = (
        "uid",
        "did",
        "url",
        "urlMetaData",
        "taskUid",
        "type",
        "createdAt",
        "updatedAt",
        "isDeleted",
        "urlIndex",
    )
    UID_FIELD_NUMBER: _ClassVar[int]
    DID_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    URLMETADATA_FIELD_NUMBER: _ClassVar[int]
    TASKUID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    UPDATEDAT_FIELD_NUMBER: _ClassVar[int]
    ISDELETED_FIELD_NUMBER: _ClassVar[int]
    URLINDEX_FIELD_NUMBER: _ClassVar[int]
    uid: str
    did: str
    url: str
    urlMetaData: _containers.RepeatedCompositeFieldContainer[UrlMetaData]
    taskUid: str
    type: _imagecontent_pb2.ImageContentTypeEnum
    createdAt: int
    updatedAt: int
    isDeleted: bool
    urlIndex: int
    def __init__(
        self,
        uid: _Optional[str] = ...,
        did: _Optional[str] = ...,
        url: _Optional[str] = ...,
        urlMetaData: _Optional[_Iterable[_Union[UrlMetaData, _Mapping]]] = ...,
        taskUid: _Optional[str] = ...,
        type: _Optional[_Union[_imagecontent_pb2.ImageContentTypeEnum, str]] = ...,
        createdAt: _Optional[int] = ...,
        updatedAt: _Optional[int] = ...,
        isDeleted: bool = ...,
        urlIndex: _Optional[int] = ...,
    ) -> None: ...

class UrlMetaData(_message.Message):
    __slots__ = ("index", "url")
    INDEX_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    index: int
    url: str
    def __init__(self, index: _Optional[int] = ..., url: _Optional[str] = ...) -> None: ...



from yeying.api.common import message_pb2 as _message_pb2
from yeying.api.common import code_pb2 as _code_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class ContentType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ARTICLE: _ClassVar[ContentType]

ARTICLE: ContentType

class SearchRequest(_message.Message):
    __slots__ = ("articleMetadata",)
    ARTICLEMETADATA_FIELD_NUMBER: _ClassVar[int]
    articleMetadata: _containers.RepeatedCompositeFieldContainer[KnowledgeMetadata]
    def __init__(self, articleMetadata: _Optional[_Iterable[_Union[KnowledgeMetadata, _Mapping]]] = ...) -> None: ...

class SearchResponse(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class KnowledgeMetadata(_message.Message):
    __slots__ = ("format", "hash", "author", "source", "publishTime", "keyword", "summary", "content")
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    AUTHOR_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    PUBLISHTIME_FIELD_NUMBER: _ClassVar[int]
    KEYWORD_FIELD_NUMBER: _ClassVar[int]
    SUMMARY_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    format: _code_pb2.DigitalFormatEnum
    hash: str
    author: str
    source: str
    publishTime: str
    keyword: str
    summary: str
    content: str
    def __init__(
        self,
        format: _Optional[_Union[_code_pb2.DigitalFormatEnum, str]] = ...,
        hash: _Optional[str] = ...,
        author: _Optional[str] = ...,
        source: _Optional[str] = ...,
        publishTime: _Optional[str] = ...,
        keyword: _Optional[str] = ...,
        summary: _Optional[str] = ...,
        content: _Optional[str] = ...,
    ) -> None: ...

class AppendMetadata(_message.Message):
    __slots__ = ("hash", "subscriber", "content")
    HASH_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIBER_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    hash: str
    subscriber: str
    content: str
    def __init__(
        self, hash: _Optional[str] = ..., subscriber: _Optional[str] = ..., content: _Optional[str] = ...
    ) -> None: ...

class AppendRequest(_message.Message):
    __slots__ = ("appendMetadata",)
    APPENDMETADATA_FIELD_NUMBER: _ClassVar[int]
    appendMetadata: _containers.RepeatedCompositeFieldContainer[AppendMetadata]
    def __init__(self, appendMetadata: _Optional[_Iterable[_Union[AppendMetadata, _Mapping]]] = ...) -> None: ...

class AppendResponse(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...



# -*- coding:utf-8 -*-
import binascii
import hashlib

from google.protobuf.json_format import MessageToJson

from yeying.client.provider.base_provider import BaseProvider
from yeying.client.utils.date_utils import get_current_utc_string
from yeying.api.asset import block_pb2_grpc, block_pb2
import grpc
from yeying.api.common import message_pb2, code_pb2, ResponseCodeEnum
from yeying.client.utils import log_utils

log = log_utils.get_logger(__name__)

"""
用于与区块链交互，提供数据的获取和存储功能
"""
class BlockProvider(BaseProvider):

    def __init__(self, **kw):
        super(BlockProvider, self).__init__(**kw)
        # 资产元信息
        self.block_client = block_pb2_grpc.BlockStub(grpc.insecure_channel(self.option.proxy))

    def get_owner(self) -> str:
        """
        获取当前用户的 DID（所有者）
        :return:返回当前用户的 DID
        """
        return self.authenticate.get_did()

    def confirm(self, block: block_pb2.BlockMetadata) -> block_pb2.ConfirmBlockResponse:
        """
        发送确认请求到后端服务，并验证返回的块元数据签名
        :param block:块元数据对象
        :return:返回确认块的响应体
        """
        body = block_pb2.ConfirmBlockRequestBody(block=block)
        header = self.authenticate.create_header(body=body)
        request = block_pb2.ConfirmBlockRequest(header=header, body=body)
        print(f"confirm request={MessageToJson(request)}")
        response: block_pb2.ConfirmBlockResponse = self.block_client.Confirm(request)
        print(f"confirm response={MessageToJson(response)}")
        if ResponseCodeEnum.OK != response.body.status.code:
            raise Exception(f"confirm error, response={MessageToJson(response)}")
        return response

    def get(self, namespace_id: str, _hash: str) -> block_pb2.GetBlockResponse:
        """
        获取资产块数据。
        :param namespace_id:资产块命名空间
        :param _hash:要获取的资产块哈希值
        :return:区块数据详情，包括数据和元数据
        """
        body = block_pb2.GetBlockRequestBody(namespaceId=namespace_id, hash=_hash)
        header = self.authenticate.create_header(body=body)
        request = block_pb2.GetBlockRequest(header=header, body=body)
        response: block_pb2.GetBlockResponse = self.block_client.Get(request)
        if ResponseCodeEnum.OK != response.body.status.code:
            raise Exception(f"get error, response={MessageToJson(response)}")
        return response

    def put(self, namespace_id: str, data: bytes) -> block_pb2.PutBlockResponse:
        """
        上传块数据,发送块数据和元数据到后端服务，并验证返回的块元数据签名
        :param namespace_id:命名空间ID
        :param data:块数据
        :return:资产块元信息
        """
        # 签名
        block = block_pb2.BlockMetadata(
            namespaceId=namespace_id,
            uploader=self.authenticate.get_did(),
            owner=self.authenticate.get_did(),
            hash=binascii.hexlify(hashlib.sha256(data).digest()).decode("ascii"),
            size=len(data),
            createdAt=get_current_utc_string(),
        )
        # 对资产块元数据进行签名，并更新元数据的`signature`字段。
        block.signature = self.authenticate.sign_data(block.SerializeToString())
        response = self.confirm(block)
        existing = response.body.block
        print(f"existing={MessageToJson(existing)}")
        if MessageToJson(existing) != "{}":
            return self.__createPutBlockResponse__(existing)
        body = block_pb2.PutBlockRequestBody(block=block)
        header = self.authenticate.create_header(body=body)
        request = block_pb2.PutBlockRequest(header=header, body=body, data=data)
        response2: block_pb2.PutBlockResponse = self.block_client.Put(request)
        print(f"put response2={MessageToJson(response2)}")
        if ResponseCodeEnum.OK != response2.body.status.code:
            raise Exception(f"put error, response={MessageToJson(response2)}")
        return response2

    def __createPutBlockResponse__(self, block: block_pb2.BlockMetadata):
        status = message_pb2.ResponseStatus(code=code_pb2.ALREADY_EXISTS)
        body = block_pb2.PutBlockResponseBody(status=status, block=block)
        return block_pb2.PutBlockResponse(header=self.authenticate.create_header(body=body), body=body)



# Generated by protobuf_init. Do not edit manually.
from .registry_pb2 import ListRequest
from .registry_pb2 import ListResponse
from .registry_pb2 import ExitRequest
from .registry_pb2 import Peer
from .registry_pb2 import ExitResponse
from .registry_pb2 import JoinRequest
from .registry_pb2 import JoinResponse
from .registry_pb2 import Contract
from .registry_pb2 import RegisterStatus
from .registry_pb2_grpc import NetworkServicer
from .registry_pb2_grpc import NetworkStub
from .registry_pb2_grpc import add_NetworkServicer_to_server
from .registry_pb2_grpc import Network



from yeying.api.common import message_pb2 as _message_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    PENDING: _ClassVar[Status]
    PROCESSED: _ClassVar[Status]
    FAILED: _ClassVar[Status]

class SenderType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    USER: _ClassVar[SenderType]
    SYSTEM: _ClassVar[SenderType]
PENDING: Status
PROCESSED: Status
FAILED: Status
USER: SenderType
SYSTEM: SenderType

class CreateSessionRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CreateSessionRequestBody
    def __init__(self, header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ..., body: _Optional[_Union[CreateSessionRequestBody, _Mapping]] = ...) -> None: ...

class CreateSessionRequestBody(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class CreateSessionResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CreateSessionResponseBody
    def __init__(self, header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ..., body: _Optional[_Union[CreateSessionResponseBody, _Mapping]] = ...) -> None: ...

class CreateSessionResponseBody(_message.Message):
    __slots__ = ("status", "memoryKey")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    MEMORYKEY_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    memoryKey: str
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ..., memoryKey: _Optional[str] = ...) -> None: ...

class AddMessageRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AddMessageRequestBody
    def __init__(self, header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ..., body: _Optional[_Union[AddMessageRequestBody, _Mapping]] = ...) -> None: ...

class AddMessageRequestBody(_message.Message):
    __slots__ = ("memoryKey", "urls", "timestamp")
    MEMORYKEY_FIELD_NUMBER: _ClassVar[int]
    URLS_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    memoryKey: str
    urls: _containers.RepeatedScalarFieldContainer[str]
    timestamp: int
    def __init__(self, memoryKey: _Optional[str] = ..., urls: _Optional[_Iterable[str]] = ..., timestamp: _Optional[int] = ...) -> None: ...

class AddMessageResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AddMessageResponseBody
    def __init__(self, header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ..., body: _Optional[_Union[AddMessageResponseBody, _Mapping]] = ...) -> None: ...

class AddMessageResponseBody(_message.Message):
    __slots__ = ("status", "errorMessage")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    ERRORMESSAGE_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    errorMessage: str
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ..., errorMessage: _Optional[str] = ...) -> None: ...

class DeleteMessageRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DeleteMessageRequestBody
    def __init__(self, header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ..., body: _Optional[_Union[DeleteMessageRequestBody, _Mapping]] = ...) -> None: ...

class DeleteMessageRequestBody(_message.Message):
    __slots__ = ("memoryKey", "urls")
    MEMORYKEY_FIELD_NUMBER: _ClassVar[int]
    URLS_FIELD_NUMBER: _ClassVar[int]
    memoryKey: str
    urls: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, memoryKey: _Optional[str] = ..., urls: _Optional[_Iterable[str]] = ...) -> None: ...

class DeleteMessageResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DeleteMessageResponseBody
    def __init__(self, header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ..., body: _Optional[_Union[DeleteMessageResponseBody, _Mapping]] = ...) -> None: ...

class DeleteMessageResponseBody(_message.Message):
    __slots__ = ("status", "errorMessage")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    ERRORMESSAGE_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    errorMessage: str
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ..., errorMessage: _Optional[str] = ...) -> None: ...

class InteractionMetadata(_message.Message):
    __slots__ = ("memoryKey", "urls", "urlTimestamp", "status")
    MEMORYKEY_FIELD_NUMBER: _ClassVar[int]
    URLS_FIELD_NUMBER: _ClassVar[int]
    URLTIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    memoryKey: str
    urls: _containers.RepeatedScalarFieldContainer[str]
    urlTimestamp: int
    status: Status
    def __init__(self, memoryKey: _Optional[str] = ..., urls: _Optional[_Iterable[str]] = ..., urlTimestamp: _Optional[int] = ..., status: _Optional[_Union[Status, str]] = ...) -> None: ...

class MainHistoryMetaData(_message.Message):
    __slots__ = ("memoryKey", "messageId", "messageContent", "vectorEmbedding", "createdAt", "updatedAt", "isDeleted", "isSummary", "senderType")
    MEMORYKEY_FIELD_NUMBER: _ClassVar[int]
    MESSAGEID_FIELD_NUMBER: _ClassVar[int]
    MESSAGECONTENT_FIELD_NUMBER: _ClassVar[int]
    VECTOREMBEDDING_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    UPDATEDAT_FIELD_NUMBER: _ClassVar[int]
    ISDELETED_FIELD_NUMBER: _ClassVar[int]
    ISSUMMARY_FIELD_NUMBER: _ClassVar[int]
    SENDERTYPE_FIELD_NUMBER: _ClassVar[int]
    memoryKey: str
    messageId: int
    messageContent: str
    vectorEmbedding: bytes
    createdAt: int
    updatedAt: int
    isDeleted: bool
    isSummary: bool
    senderType: SenderType
    def __init__(self, memoryKey: _Optional[str] = ..., messageId: _Optional[int] = ..., messageContent: _Optional[str] = ..., vectorEmbedding: _Optional[bytes] = ..., createdAt: _Optional[int] = ..., updatedAt: _Optional[int] = ..., isDeleted: bool = ..., isSummary: bool = ..., senderType: _Optional[_Union[SenderType, str]] = ...) -> None: ...

class VectorIndex(_message.Message):
    __slots__ = ("memoryKey", "messageId", "vector", "createdAt", "updatedAt")
    MEMORYKEY_FIELD_NUMBER: _ClassVar[int]
    MESSAGEID_FIELD_NUMBER: _ClassVar[int]
    VECTOR_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    UPDATEDAT_FIELD_NUMBER: _ClassVar[int]
    memoryKey: str
    messageId: int
    vector: bytes
    createdAt: int
    updatedAt: int
    def __init__(self, memoryKey: _Optional[str] = ..., messageId: _Optional[int] = ..., vector: _Optional[bytes] = ..., createdAt: _Optional[int] = ..., updatedAt: _Optional[int] = ...) -> None: ...



from yeying.api.common import message_pb2 as _message_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SignRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: SignRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[SignRequestBody, _Mapping]] = ...,
    ) -> None: ...

class SignRequestBody(_message.Message):
    __slots__ = ("domain", "csr")
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    CSR_FIELD_NUMBER: _ClassVar[int]
    domain: str
    csr: str
    def __init__(self, domain: _Optional[str] = ..., csr: _Optional[str] = ...) -> None: ...

class SignResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: SignResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[SignResponseBody, _Mapping]] = ...,
    ) -> None: ...

class CertificateMetadata(_message.Message):
    __slots__ = ("crt", "ca")
    CRT_FIELD_NUMBER: _ClassVar[int]
    CA_FIELD_NUMBER: _ClassVar[int]
    crt: str
    ca: str
    def __init__(self, crt: _Optional[str] = ..., ca: _Optional[str] = ...) -> None: ...

class SignResponseBody(_message.Message):
    __slots__ = ("status", "certificate")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CERTIFICATE_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    certificate: CertificateMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        certificate: _Optional[_Union[CertificateMetadata, _Mapping]] = ...,
    ) -> None: ...

class GetRequest(_message.Message):
    __slots__ = ("header",)
    HEADER_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    def __init__(self, header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...) -> None: ...

class GetResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: GetResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[GetResponseBody, _Mapping]] = ...,
    ) -> None: ...

class GetResponseBody(_message.Message):
    __slots__ = ("status", "certificate")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CERTIFICATE_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    certificate: CertificateMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        certificate: _Optional[_Union[CertificateMetadata, _Mapping]] = ...,
    ) -> None: ...



# -*- coding:utf-8 -*-
"""用于更新和计算数据的哈希值，并最终返回计算结果。"""
import hashlib

from yeying.client.utils.signature_utils import encode_hex


class Digest:

    def __init__(self):
        """创建一个新的 Digest 实例，并初始化哈希状态。默认使用 SHA-256 初始哈希值。"""
        # 初始化 SHA-256 哈希状态
        self.sha256 = hashlib.sha256()

    def update(self, data: bytes):
        """
        更新哈希计算过程。

        :param data: 新的数据块，用于更新哈希值
        :return: 当前实例，便于链式调用
        """
        self.sha256.update(data)
        return self

    def digest(self):
        return self.sha256.digest()


# 测试代码
if __name__ == "__main__":
    digest = Digest()
    digest.update(b"Hello, ")
    digest.update(b"world!")
    result = digest.digest()
    print(encode_hex(result))



from yeying.api.common import message_pb2 as _message_pb2
from yeying.api.common import code_pb2 as _code_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class MessageRoleEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    MESSAGE_ROLE_UNKNOWN: _ClassVar[MessageRoleEnum]
    MESSAGE_ROLE_ASSISTANT: _ClassVar[MessageRoleEnum]
    MESSAGE_ROLE_USER: _ClassVar[MessageRoleEnum]
    MESSAGE_ROLE_SYSTEM: _ClassVar[MessageRoleEnum]

class ContentTypeEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    CONTENT_TYPE_UNKNOWN: _ClassVar[ContentTypeEnum]
    CONTENT_TYPE_TEXT: _ClassVar[ContentTypeEnum]
    CONTENT_TYPE_IMAGE: _ClassVar[ContentTypeEnum]
    CONTENT_TYPE_AUDIO: _ClassVar[ContentTypeEnum]
    CONTENT_TYPE_VIDEO: _ClassVar[ContentTypeEnum]
    CONTENT_TYPE_DOCUMENT: _ClassVar[ContentTypeEnum]

MESSAGE_ROLE_UNKNOWN: MessageRoleEnum
MESSAGE_ROLE_ASSISTANT: MessageRoleEnum
MESSAGE_ROLE_USER: MessageRoleEnum
MESSAGE_ROLE_SYSTEM: MessageRoleEnum
CONTENT_TYPE_UNKNOWN: ContentTypeEnum
CONTENT_TYPE_TEXT: ContentTypeEnum
CONTENT_TYPE_IMAGE: ContentTypeEnum
CONTENT_TYPE_AUDIO: ContentTypeEnum
CONTENT_TYPE_VIDEO: ContentTypeEnum
CONTENT_TYPE_DOCUMENT: ContentTypeEnum

class CompleteRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CompleteRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[CompleteRequestBody, _Mapping]] = ...,
    ) -> None: ...

class CompleteRequestBody(_message.Message):
    __slots__ = ("sessionId", "promptId", "providerId", "model", "stream", "messages")
    SESSIONID_FIELD_NUMBER: _ClassVar[int]
    PROMPTID_FIELD_NUMBER: _ClassVar[int]
    PROVIDERID_FIELD_NUMBER: _ClassVar[int]
    MODEL_FIELD_NUMBER: _ClassVar[int]
    STREAM_FIELD_NUMBER: _ClassVar[int]
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    sessionId: str
    promptId: str
    providerId: str
    model: str
    stream: bool
    messages: _containers.RepeatedCompositeFieldContainer[Message]
    def __init__(
        self,
        sessionId: _Optional[str] = ...,
        promptId: _Optional[str] = ...,
        providerId: _Optional[str] = ...,
        model: _Optional[str] = ...,
        stream: bool = ...,
        messages: _Optional[_Iterable[_Union[Message, _Mapping]]] = ...,
    ) -> None: ...

class Message(_message.Message):
    __slots__ = ("role", "content")
    ROLE_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    role: MessageRoleEnum
    content: Content
    def __init__(
        self, role: _Optional[_Union[MessageRoleEnum, str]] = ..., content: _Optional[_Union[Content, _Mapping]] = ...
    ) -> None: ...

class Content(_message.Message):
    __slots__ = ("type", "data")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    type: ContentTypeEnum
    data: str
    def __init__(self, type: _Optional[_Union[ContentTypeEnum, str]] = ..., data: _Optional[str] = ...) -> None: ...

class Answer(_message.Message):
    __slots__ = ("model", "id", "createdAt", "choices")
    MODEL_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    CHOICES_FIELD_NUMBER: _ClassVar[int]
    model: str
    id: str
    createdAt: int
    choices: _containers.RepeatedCompositeFieldContainer[Choice]
    def __init__(
        self,
        model: _Optional[str] = ...,
        id: _Optional[str] = ...,
        createdAt: _Optional[int] = ...,
        choices: _Optional[_Iterable[_Union[Choice, _Mapping]]] = ...,
    ) -> None: ...

class CompleteResponse(_message.Message):
    __slots__ = ("head", "body", "tail")
    HEAD_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    TAIL_FIELD_NUMBER: _ClassVar[int]
    head: CompleteResponseHead
    body: CompleteResponseBody
    tail: CompleteResponseTail
    def __init__(
        self,
        head: _Optional[_Union[CompleteResponseHead, _Mapping]] = ...,
        body: _Optional[_Union[CompleteResponseBody, _Mapping]] = ...,
        tail: _Optional[_Union[CompleteResponseTail, _Mapping]] = ...,
    ) -> None: ...

class CompleteResponseHead(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CompleteResponseHeadBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[CompleteResponseHeadBody, _Mapping]] = ...,
    ) -> None: ...

class CompleteResponseHeadBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class CompleteResponseBody(_message.Message):
    __slots__ = ("data",)
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: str
    def __init__(self, data: _Optional[str] = ...) -> None: ...

class CompleteResponseTail(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CompleteResponseTailBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[CompleteResponseTailBody, _Mapping]] = ...,
    ) -> None: ...

class CompleteResponseTailBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class GenerateRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: GenerateRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[GenerateRequestBody, _Mapping]] = ...,
    ) -> None: ...

class GenerateRequestBody(_message.Message):
    __slots__ = ("llmId", "model", "prompt", "responseContentFormat", "count", "size", "quality", "style")
    LLMID_FIELD_NUMBER: _ClassVar[int]
    MODEL_FIELD_NUMBER: _ClassVar[int]
    PROMPT_FIELD_NUMBER: _ClassVar[int]
    RESPONSECONTENTFORMAT_FIELD_NUMBER: _ClassVar[int]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    QUALITY_FIELD_NUMBER: _ClassVar[int]
    STYLE_FIELD_NUMBER: _ClassVar[int]
    llmId: str
    model: str
    prompt: str
    responseContentFormat: _code_pb2.ContentFormatEnum
    count: int
    size: str
    quality: str
    style: str
    def __init__(
        self,
        llmId: _Optional[str] = ...,
        model: _Optional[str] = ...,
        prompt: _Optional[str] = ...,
        responseContentFormat: _Optional[_Union[_code_pb2.ContentFormatEnum, str]] = ...,
        count: _Optional[int] = ...,
        size: _Optional[str] = ...,
        quality: _Optional[str] = ...,
        style: _Optional[str] = ...,
    ) -> None: ...

class GenerateResponse(_message.Message):
    __slots__ = ("head", "body", "tail")
    HEAD_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    TAIL_FIELD_NUMBER: _ClassVar[int]
    head: GenerateResponseHead
    body: GenerateResponseBody
    tail: GenerateResponseTail
    def __init__(
        self,
        head: _Optional[_Union[GenerateResponseHead, _Mapping]] = ...,
        body: _Optional[_Union[GenerateResponseBody, _Mapping]] = ...,
        tail: _Optional[_Union[GenerateResponseTail, _Mapping]] = ...,
    ) -> None: ...

class GenerateResponseHead(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: GenerateResponseHeadBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[GenerateResponseHeadBody, _Mapping]] = ...,
    ) -> None: ...

class GenerateResponseHeadBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class GenerateResponseBody(_message.Message):
    __slots__ = ("data",)
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: str
    def __init__(self, data: _Optional[str] = ...) -> None: ...

class GenerateResponseTail(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: GenerateResponseTailBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[GenerateResponseTailBody, _Mapping]] = ...,
    ) -> None: ...

class GenerateResponseTailBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class TextPrompt(_message.Message):
    __slots__ = ("message",)
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    message: str
    def __init__(self, message: _Optional[str] = ...) -> None: ...

class ImagePrompt(_message.Message):
    __slots__ = ("message", "mask", "image")
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    MASK_FIELD_NUMBER: _ClassVar[int]
    IMAGE_FIELD_NUMBER: _ClassVar[int]
    message: str
    mask: bytes
    image: bytes
    def __init__(
        self, message: _Optional[str] = ..., mask: _Optional[bytes] = ..., image: _Optional[bytes] = ...
    ) -> None: ...

class ImageResult(_message.Message):
    __slots__ = ("responseContentFormat", "count", "size", "quality", "style")
    RESPONSECONTENTFORMAT_FIELD_NUMBER: _ClassVar[int]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    QUALITY_FIELD_NUMBER: _ClassVar[int]
    STYLE_FIELD_NUMBER: _ClassVar[int]
    responseContentFormat: _code_pb2.ContentFormatEnum
    count: int
    size: str
    quality: str
    style: str
    def __init__(
        self,
        responseContentFormat: _Optional[_Union[_code_pb2.ContentFormatEnum, str]] = ...,
        count: _Optional[int] = ...,
        size: _Optional[str] = ...,
        quality: _Optional[str] = ...,
        style: _Optional[str] = ...,
    ) -> None: ...

class EditRequest(_message.Message):
    __slots__ = ("did", "llmId", "model", "srcType", "desType", "textPrompt", "imagePrompt", "imageResult")
    DID_FIELD_NUMBER: _ClassVar[int]
    LLMID_FIELD_NUMBER: _ClassVar[int]
    MODEL_FIELD_NUMBER: _ClassVar[int]
    SRCTYPE_FIELD_NUMBER: _ClassVar[int]
    DESTYPE_FIELD_NUMBER: _ClassVar[int]
    TEXTPROMPT_FIELD_NUMBER: _ClassVar[int]
    IMAGEPROMPT_FIELD_NUMBER: _ClassVar[int]
    IMAGERESULT_FIELD_NUMBER: _ClassVar[int]
    did: str
    llmId: str
    model: str
    srcType: _code_pb2.DigitalFormatEnum
    desType: _code_pb2.DigitalFormatEnum
    textPrompt: TextPrompt
    imagePrompt: ImagePrompt
    imageResult: ImageResult
    def __init__(
        self,
        did: _Optional[str] = ...,
        llmId: _Optional[str] = ...,
        model: _Optional[str] = ...,
        srcType: _Optional[_Union[_code_pb2.DigitalFormatEnum, str]] = ...,
        desType: _Optional[_Union[_code_pb2.DigitalFormatEnum, str]] = ...,
        textPrompt: _Optional[_Union[TextPrompt, _Mapping]] = ...,
        imagePrompt: _Optional[_Union[ImagePrompt, _Mapping]] = ...,
        imageResult: _Optional[_Union[ImageResult, _Mapping]] = ...,
    ) -> None: ...

class EditResponse(_message.Message):
    __slots__ = ("status", "base64", "bytes")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    BASE64_FIELD_NUMBER: _ClassVar[int]
    BYTES_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    base64: str
    bytes: bytes
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        base64: _Optional[str] = ...,
        bytes: _Optional[bytes] = ...,
    ) -> None: ...

class TranslateRequest(_message.Message):
    __slots__ = ("did", "llmId", "instance")
    DID_FIELD_NUMBER: _ClassVar[int]
    LLMID_FIELD_NUMBER: _ClassVar[int]
    INSTANCE_FIELD_NUMBER: _ClassVar[int]
    did: str
    llmId: str
    instance: str
    def __init__(
        self, did: _Optional[str] = ..., llmId: _Optional[str] = ..., instance: _Optional[str] = ...
    ) -> None: ...

class TranslateResponse(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class ConvertRequest(_message.Message):
    __slots__ = ("did", "llmId", "instance")
    DID_FIELD_NUMBER: _ClassVar[int]
    LLMID_FIELD_NUMBER: _ClassVar[int]
    INSTANCE_FIELD_NUMBER: _ClassVar[int]
    did: str
    llmId: str
    instance: str
    def __init__(
        self, did: _Optional[str] = ..., llmId: _Optional[str] = ..., instance: _Optional[str] = ...
    ) -> None: ...

class ConvertResponse(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class Choice(_message.Message):
    __slots__ = ("index", "role", "content", "finishReason")
    INDEX_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    FINISHREASON_FIELD_NUMBER: _ClassVar[int]
    index: int
    role: MessageRoleEnum
    content: Content
    finishReason: str
    def __init__(
        self,
        index: _Optional[int] = ...,
        role: _Optional[_Union[MessageRoleEnum, str]] = ...,
        content: _Optional[_Union[Content, _Mapping]] = ...,
        finishReason: _Optional[str] = ...,
    ) -> None: ...

class SpeechRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SpeechResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yeying.api.identity import identity_pb2 as yeying_dot_api_dot_identity_dot_identity__pb2

GRPC_GENERATED_VERSION = "1.68.1"
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower

    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f"The grpc package installed is at version {GRPC_VERSION},"
        + f" but the generated code in yeying/api/identity/identity_pb2_grpc.py depends on"
        + f" grpcio>={GRPC_GENERATED_VERSION}."
        + f" Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}"
        + f" or downgrade your generated code using grpcio-tools<={GRPC_VERSION}."
    )


class IdentityStub(object):
    """提供身份托管和维护服务，目前还不支持托管加密的身份，需要有资质，需要补齐的能力；
    1、至少二要素身份认证；
    2、保护隐私零知识证名；
    2、支持密钥恢复；
    3、服务器故障导致丢失，需要支持分散式存储；
    4、支持加密硬件；
    5、至少要两把密钥，一把由身份所有者保管，一把是服务保管；
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Deposit = channel.unary_unary(
            "/yeying.api.identity.Identity/Deposit",
            request_serializer=yeying_dot_api_dot_identity_dot_identity__pb2.DepositRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_identity_dot_identity__pb2.DepositResponse.FromString,
            _registered_method=True,
        )
        self.Retrieve = channel.unary_unary(
            "/yeying.api.identity.Identity/Retrieve",
            request_serializer=yeying_dot_api_dot_identity_dot_identity__pb2.RetrieveRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_identity_dot_identity__pb2.RetrieveResponse.FromString,
            _registered_method=True,
        )
        self.Query = channel.unary_unary(
            "/yeying.api.identity.Identity/Query",
            request_serializer=yeying_dot_api_dot_identity_dot_identity__pb2.QueryRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_identity_dot_identity__pb2.QueryResponse.FromString,
            _registered_method=True,
        )
        self.Share = channel.unary_unary(
            "/yeying.api.identity.Identity/Share",
            request_serializer=yeying_dot_api_dot_identity_dot_identity__pb2.ShareRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_identity_dot_identity__pb2.ShareResponse.FromString,
            _registered_method=True,
        )
        self.Cancel = channel.unary_unary(
            "/yeying.api.identity.Identity/Cancel",
            request_serializer=yeying_dot_api_dot_identity_dot_identity__pb2.CancelRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_identity_dot_identity__pb2.CancelResponse.FromString,
            _registered_method=True,
        )


class IdentityServicer(object):
    """提供身份托管和维护服务，目前还不支持托管加密的身份，需要有资质，需要补齐的能力；
    1、至少二要素身份认证；
    2、保护隐私零知识证名；
    2、支持密钥恢复；
    3、服务器故障导致丢失，需要支持分散式存储；
    4、支持加密硬件；
    5、至少要两把密钥，一把由身份所有者保管，一把是服务保管；
    """

    def Deposit(self, request, context):
        """身份托管"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Retrieve(self, request, context):
        """取回身份"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Query(self, request, context):
        """查询身份名片"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Share(self, request, context):
        """分享身份名片"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Cancel(self, request, context):
        """取消托管"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_IdentityServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Deposit": grpc.unary_unary_rpc_method_handler(
            servicer.Deposit,
            request_deserializer=yeying_dot_api_dot_identity_dot_identity__pb2.DepositRequest.FromString,
            response_serializer=yeying_dot_api_dot_identity_dot_identity__pb2.DepositResponse.SerializeToString,
        ),
        "Retrieve": grpc.unary_unary_rpc_method_handler(
            servicer.Retrieve,
            request_deserializer=yeying_dot_api_dot_identity_dot_identity__pb2.RetrieveRequest.FromString,
            response_serializer=yeying_dot_api_dot_identity_dot_identity__pb2.RetrieveResponse.SerializeToString,
        ),
        "Query": grpc.unary_unary_rpc_method_handler(
            servicer.Query,
            request_deserializer=yeying_dot_api_dot_identity_dot_identity__pb2.QueryRequest.FromString,
            response_serializer=yeying_dot_api_dot_identity_dot_identity__pb2.QueryResponse.SerializeToString,
        ),
        "Share": grpc.unary_unary_rpc_method_handler(
            servicer.Share,
            request_deserializer=yeying_dot_api_dot_identity_dot_identity__pb2.ShareRequest.FromString,
            response_serializer=yeying_dot_api_dot_identity_dot_identity__pb2.ShareResponse.SerializeToString,
        ),
        "Cancel": grpc.unary_unary_rpc_method_handler(
            servicer.Cancel,
            request_deserializer=yeying_dot_api_dot_identity_dot_identity__pb2.CancelRequest.FromString,
            response_serializer=yeying_dot_api_dot_identity_dot_identity__pb2.CancelResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("yeying.api.identity.Identity", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers("yeying.api.identity.Identity", rpc_method_handlers)


# This class is part of an EXPERIMENTAL API.
class Identity(object):
    """提供身份托管和维护服务，目前还不支持托管加密的身份，需要有资质，需要补齐的能力；
    1、至少二要素身份认证；
    2、保护隐私零知识证名；
    2、支持密钥恢复；
    3、服务器故障导致丢失，需要支持分散式存储；
    4、支持加密硬件；
    5、至少要两把密钥，一把由身份所有者保管，一把是服务保管；
    """

    @staticmethod
    def Deposit(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.identity.Identity/Deposit",
            yeying_dot_api_dot_identity_dot_identity__pb2.DepositRequest.SerializeToString,
            yeying_dot_api_dot_identity_dot_identity__pb2.DepositResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Retrieve(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.identity.Identity/Retrieve",
            yeying_dot_api_dot_identity_dot_identity__pb2.RetrieveRequest.SerializeToString,
            yeying_dot_api_dot_identity_dot_identity__pb2.RetrieveResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Query(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.identity.Identity/Query",
            yeying_dot_api_dot_identity_dot_identity__pb2.QueryRequest.SerializeToString,
            yeying_dot_api_dot_identity_dot_identity__pb2.QueryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Share(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.identity.Identity/Share",
            yeying_dot_api_dot_identity_dot_identity__pb2.ShareRequest.SerializeToString,
            yeying_dot_api_dot_identity_dot_identity__pb2.ShareResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Cancel(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.identity.Identity/Cancel",
            yeying_dot_api_dot_identity_dot_identity__pb2.CancelRequest.SerializeToString,
            yeying_dot_api_dot_identity_dot_identity__pb2.CancelResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yeying.api.asset import block_pb2 as yeying_dot_api_dot_asset_dot_block__pb2

GRPC_GENERATED_VERSION = "1.68.1"
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower

    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f"The grpc package installed is at version {GRPC_VERSION},"
        + f" but the generated code in yeying/api/asset/block_pb2_grpc.py depends on"
        + f" grpcio>={GRPC_GENERATED_VERSION}."
        + f" Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}"
        + f" or downgrade your generated code using grpcio-tools<={GRPC_VERSION}."
    )


class BlockStub(object):
    """*
    站在存储供应商的角度，数据和资产是有区别，数据有可能是有价值，也可能没有价值，但是存储供应商是没有感知，只有用户能够感知到。当用户和存储供应商之间签
    约了以后，用户明确告知存储供应商数据是有价值的，并愿意支付一定的报酬，存储供应商才会认为数据是资产，这种资产可以在不同的存储供应商之间流通。在签约之
    前，数据存储在临时存储区不能流通，只是某个存储供应商和用户之间临时的约定，所以也不会有版本的概念
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Put = channel.unary_unary(
            "/yeying.api.asset.Block/Put",
            request_serializer=yeying_dot_api_dot_asset_dot_block__pb2.PutBlockRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_asset_dot_block__pb2.PutBlockResponse.FromString,
            _registered_method=True,
        )
        self.StreamPut = channel.stream_stream(
            "/yeying.api.asset.Block/StreamPut",
            request_serializer=yeying_dot_api_dot_asset_dot_block__pb2.StreamPutBlockRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_asset_dot_block__pb2.StreamPutBlockResponse.FromString,
            _registered_method=True,
        )
        self.Confirm = channel.unary_unary(
            "/yeying.api.asset.Block/Confirm",
            request_serializer=yeying_dot_api_dot_asset_dot_block__pb2.ConfirmBlockRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_asset_dot_block__pb2.ConfirmBlockResponse.FromString,
            _registered_method=True,
        )
        self.Get = channel.unary_unary(
            "/yeying.api.asset.Block/Get",
            request_serializer=yeying_dot_api_dot_asset_dot_block__pb2.GetBlockRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_asset_dot_block__pb2.GetBlockResponse.FromString,
            _registered_method=True,
        )
        self.StreamGet = channel.stream_stream(
            "/yeying.api.asset.Block/StreamGet",
            request_serializer=yeying_dot_api_dot_asset_dot_block__pb2.StreamGetBlockRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_asset_dot_block__pb2.StreamGetBlockResponse.FromString,
            _registered_method=True,
        )


class BlockServicer(object):
    """*
    站在存储供应商的角度，数据和资产是有区别，数据有可能是有价值，也可能没有价值，但是存储供应商是没有感知，只有用户能够感知到。当用户和存储供应商之间签
    约了以后，用户明确告知存储供应商数据是有价值的，并愿意支付一定的报酬，存储供应商才会认为数据是资产，这种资产可以在不同的存储供应商之间流通。在签约之
    前，数据存储在临时存储区不能流通，只是某个存储供应商和用户之间临时的约定，所以也不会有版本的概念
    """

    def Put(self, request, context):
        """*
        前端浏览器不支持client stream，按块上传接口，以块的形式放在临时存储区，资产签约时，这个块就会被挪到数据区，持久化存储。
        每个资产id只会保存一个块，确保业务层面始终存储和获取最新的块，也就是会覆盖之前的资产块，如果需要形成版本，就需要及时和存储供应商之间完成签约
        形成版本。
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StreamPut(self, request_iterator, context):
        """*
        按块流式上传，1，发送chunk的简要信息；2，上传资产块的内容；3，确认资产块的完整信息；
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Confirm(self, request, context):
        """*
        检查该用户的资产块是否已经存在，如果存在则返回资产块元信息，如果不存在但是块哈希已存在则创建该用户的资产块
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Get(self, request, context):
        """*
        前端浏览器不支持server stream，提供一个非流式的下载接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StreamGet(self, request_iterator, context):
        """*
        分块出库数字内容
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_BlockServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Put": grpc.unary_unary_rpc_method_handler(
            servicer.Put,
            request_deserializer=yeying_dot_api_dot_asset_dot_block__pb2.PutBlockRequest.FromString,
            response_serializer=yeying_dot_api_dot_asset_dot_block__pb2.PutBlockResponse.SerializeToString,
        ),
        "StreamPut": grpc.stream_stream_rpc_method_handler(
            servicer.StreamPut,
            request_deserializer=yeying_dot_api_dot_asset_dot_block__pb2.StreamPutBlockRequest.FromString,
            response_serializer=yeying_dot_api_dot_asset_dot_block__pb2.StreamPutBlockResponse.SerializeToString,
        ),
        "Confirm": grpc.unary_unary_rpc_method_handler(
            servicer.Confirm,
            request_deserializer=yeying_dot_api_dot_asset_dot_block__pb2.ConfirmBlockRequest.FromString,
            response_serializer=yeying_dot_api_dot_asset_dot_block__pb2.ConfirmBlockResponse.SerializeToString,
        ),
        "Get": grpc.unary_unary_rpc_method_handler(
            servicer.Get,
            request_deserializer=yeying_dot_api_dot_asset_dot_block__pb2.GetBlockRequest.FromString,
            response_serializer=yeying_dot_api_dot_asset_dot_block__pb2.GetBlockResponse.SerializeToString,
        ),
        "StreamGet": grpc.stream_stream_rpc_method_handler(
            servicer.StreamGet,
            request_deserializer=yeying_dot_api_dot_asset_dot_block__pb2.StreamGetBlockRequest.FromString,
            response_serializer=yeying_dot_api_dot_asset_dot_block__pb2.StreamGetBlockResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("yeying.api.asset.Block", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers("yeying.api.asset.Block", rpc_method_handlers)


# This class is part of an EXPERIMENTAL API.
class Block(object):
    """*
    站在存储供应商的角度，数据和资产是有区别，数据有可能是有价值，也可能没有价值，但是存储供应商是没有感知，只有用户能够感知到。当用户和存储供应商之间签
    约了以后，用户明确告知存储供应商数据是有价值的，并愿意支付一定的报酬，存储供应商才会认为数据是资产，这种资产可以在不同的存储供应商之间流通。在签约之
    前，数据存储在临时存储区不能流通，只是某个存储供应商和用户之间临时的约定，所以也不会有版本的概念
    """

    @staticmethod
    def Put(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.asset.Block/Put",
            yeying_dot_api_dot_asset_dot_block__pb2.PutBlockRequest.SerializeToString,
            yeying_dot_api_dot_asset_dot_block__pb2.PutBlockResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def StreamPut(
        request_iterator,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            "/yeying.api.asset.Block/StreamPut",
            yeying_dot_api_dot_asset_dot_block__pb2.StreamPutBlockRequest.SerializeToString,
            yeying_dot_api_dot_asset_dot_block__pb2.StreamPutBlockResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Confirm(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.asset.Block/Confirm",
            yeying_dot_api_dot_asset_dot_block__pb2.ConfirmBlockRequest.SerializeToString,
            yeying_dot_api_dot_asset_dot_block__pb2.ConfirmBlockResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Get(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.asset.Block/Get",
            yeying_dot_api_dot_asset_dot_block__pb2.GetBlockRequest.SerializeToString,
            yeying_dot_api_dot_asset_dot_block__pb2.GetBlockResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def StreamGet(
        request_iterator,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            "/yeying.api.asset.Block/StreamGet",
            yeying_dot_api_dot_asset_dot_block__pb2.StreamGetBlockRequest.SerializeToString,
            yeying_dot_api_dot_asset_dot_block__pb2.StreamGetBlockResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )



# Generated by protobuf_init. Do not edit manually.
from .task_pb2 import CreateTaskRequest
from .task_pb2 import CreateTaskResponse
from .task_pb2 import TaskMetadata
from .task_pb2 import FetchTaskResponse
from .task_pb2 import TaskCodeEnum
from .task_pb2_grpc import TaskServicer
from .task_pb2_grpc import TaskStub
from .task_pb2_grpc import add_TaskServicer_to_server
from .task_pb2_grpc import Task
